.\" **************************************************************************
.\" *                                  _   _ ____  _
.\" *  Project                     ___| | | |  _ \| |
.\" *                             / __| | | | |_) | |
.\" *                            | (__| |_| |  _ <| |___
.\" *                             \___|\___/|_| \_\_____|
.\" *
.\" * Copyright (C) 1998 - 2022, Daniel Stenberg, <daniel@haxx.se>, et al.
.\" *
.\" * This software is licensed as described in the file COPYING, which
.\" * you should have received as part of this distribution. The terms
.\" * are also available at https://curl.se/docs/copyright.html.
.\" *
.\" * You may opt to use, copy, modify, merge, publish, distribute and/or sell
.\" * copies of the Software, and permit persons to whom the Software is
.\" * furnished to do so, under the terms of the COPYING file.
.\" *
.\" * This software is distributed on an "AS IS" basis, WITHOUT WARRANTY OF ANY
.\" * KIND, either express or implied.
.\" *
.\" * SPDX-License-Identifier: curl
.\" *
.\" **************************************************************************
.\"
.TH CURLOPT_MIME_OPTIONS 3 "2 Oct 2021" "libcurl 7.81.0" "curl_easy_setopt options"
.SH NAME
CURLOPT_MIME_OPTIONS \- set MIME option flags
.SH SYNOPSIS
.nf
#include <curl/curl.h>

CURLcode curl_easy_setopt(CURL *handle, CURLOPT_MIME_OPTIONS, long options);
.fi
.SH DESCRIPTION
Pass a long that holds a bitmask of CURLMIMEOPT_* defines. Each bit is a
Boolean flag used while encoding a MIME tree or multipart form data.

Available bits are:
.IP CURLMIMEOPT_FORMESCAPE
Tells libcurl to escape multipart form field and file names using the
backslash-escaping algorithm rather than percent-encoding (HTTP only).

Backslash-escaping consists in preceding backslashes and double quotes with
a backslash. Percent encoding maps all occurrences of double quote,
carriage return and line feed to %22, %0D and %0A respectively.

Before version 7.81.0, percent-encoding was never applied.

HTTP browsers used to do backslash-escaping in the past but have over time
transitioned to use percent-encoding. This option allows one to address
server-side applications that have not yet have been converted.

As an example, consider field or file name \fIstrange\\name"kind\fP.
When the containing multipart form is sent, this is normally transmitted as
\fIstrange\\name%22kind\fP. When this option is set, it is sent as
\fIstrange\\\\name\\"kind\fP.
.SH DEFAULT
0, meaning disabled.
.SH PROTOCOLS
HTTP, IMAP, SMTP
.SH EXAMPLE
.nf
CURL *curl = curl_easy_init();
curl_mime *form = NULL;

if(curl) {
  curl_easy_setopt(curl, CURLOPT_URL, "https://example.com");
  curl_easy_setopt(curl, CURLOPT_MIME_OPTIONS, CURLMIMEOPT_FORMESCAPE);

  form = curl_mime_init(curl);
  if(form) {
    curl_mimepart *part = curl_mime_addpart(form);

    if(part) {
      curl_mime_filedata(part, "strange\\\\file\\\\name");
      curl_mime_name(part, "strange\\"field\\"name");
      curl_easy_setopt(curl, CURLOPT_MIMEPOST, form);

      /* Perform the request */
      curl_easy_perform(curl);
    }
  }

  curl_easy_cleanup(curl);
  curl_mime_free(mime);
}
.fi
.SH AVAILABILITY
Option added in 7.81.0.
.SH RETURN VALUE
Returns CURLE_OK
.SH "SEE ALSO"
.BR CURLOPT_MIMEPOST "(3), " CURLOPT_HTTPPOST "(3)"
